@@ -15,7 +15,7 @@
 #' Several online sources list WHP names. An example is
 #' \url{https://geo.h2o.ucsd.edu/documentation/manuals/pdf/90_1/chap4.pdf}
 #'
-#' @family things related to \code{ctd} data
+#' @family things related to ctd data
 #' @family functions that interpret variable names and units from headers
 oceNames2whpNames <- function(names)
 {
@@ -67,7 +67,7 @@ oceNames2whpNames <- function(names)
 #' Several online sources list WOCE names. An example is
 #' \url{https://geo.h2o.ucsd.edu/documentation/manuals/pdf/90_1/chap4.pdf}
 #'
-#' @family things related to \code{ctd} data
+#' @family things related to ctd data
 #' @family functions that interpret variable names and units from headers
 oceUnits2whpUnits <- function(units, scales)
 {
@@ -147,7 +147,7 @@ oceUnits2whpUnits <- function(units, scales)
 #' Several online sources list WOCE names. An example is
 #' \url{https://geo.h2o.ucsd.edu/documentation/manuals/pdf/90_1/chap4.pdf}
 #'
-#' @family things related to \code{ctd} data
+#' @family things related to ctd data
 #' @family functions that interpret variable names and units from headers
 woceNames2oceNames <- function(names)
 {
@@ -195,7 +195,7 @@ woceNames2oceNames <- function(names)
 #'
 #' @author Dan Kelley
 #'
-#' @family things related to \code{ctd} data
+#' @family things related to ctd data
 #' @family functions that interpret variable names and units from headers
 woceUnit2oceUnit <- function(woceUnit)
 {
@@ -227,8 +227,11 @@ woceUnit2oceUnit <- function(woceUnit)
 
 
 #' Read a WOCE-type CTD file with First Word "CTD"
+#'
 #' @template readCtdTemplate
 #'
+#' @author Dan Kelley
+#'
 #' @details
 #' \code{read.ctd.woce()} reads files stored in the exchange format used
 #' by the World Ocean Circulation Experiment (WOCE), in which the first 4
@@ -241,8 +244,8 @@ woceUnit2oceUnit <- function(woceUnit)
 #' \code{http://woce.nodc.noaa.gov/woce_v3/wocedata_1/whp/exchange/exchange_format_desc.htm},
 #' and a sample file is at
 #' \url{https://www.nodc.noaa.gov/woce/woce_v3/wocedata_1/whp/exchange/example_ct1.csv}
-read.ctd.woce <- function(file, columns=NULL, station=NULL, missingValue, monitor=FALSE,
-                          debug=getOption("oceDebug"), processingLog, ...)
+read.ctd.woce <- function(file, columns=NULL, station=NULL, missingValue, deploymentType="unknown",
+                          monitor=FALSE, debug=getOption("oceDebug"), processingLog, ...)
 {
     if (length(grep("\\*", file))) {
         oceDebug(debug, "read.ctd.woce(file=\"", file, "\") { # will read a series of files\n", unindent=1)
@@ -252,7 +255,7 @@ read.ctd.woce <- function(file, columns=NULL, station=NULL, missingValue, monito
             pb <- txtProgressBar(1, nfiles, style=3)
         res <- vector("list", nfiles)
         for (i in 1:nfiles) {
-            res[[i]] <- read.ctd.woce(files[i], debug=debug-1)
+            res[[i]] <- read.ctd.woce(files[i], deploymentType=deploymentType, debug=debug-1)
             if (monitor)
                 setTxtProgressBar(pb, i)
         }
@@ -283,7 +286,7 @@ read.ctd.woce <- function(file, columns=NULL, station=NULL, missingValue, monito
     latitude <- longitude <- NaN
     startTime <- NULL
     waterDepth <- NA
-    date <- recovery <- NULL
+    date <- recoveryTime <- NULL
     header <- c()
     ##col.names.inferred <- NULL
     ##conductivity.standard <- 4.2914
@@ -325,7 +328,7 @@ read.ctd.woce <- function(file, columns=NULL, station=NULL, missingValue, monito
             units[[names[i]]] <- woceUnit2oceUnit(unitsOriginal[i])
         }
         for (i in seq_along(header)) {
-            message("header[", i, "=\"", header[i], "\"")
+            oceDebug(debug, " header[", i, "]=\"", header[i], "\"\n", sep="")
             if (length(grep("CRUISE", header[i], ignore.case=TRUE))) {
                 cruise<- sub("CRUISE[ ]*NAME[ ]*=[ ]*", "", header[i], ignore.case=TRUE)
                 cruise <- sub("[ ]*$", "", cruise)
@@ -366,12 +369,12 @@ read.ctd.woce <- function(file, columns=NULL, station=NULL, missingValue, monito
         res@metadata$address <- address
         res@metadata$cruise <- NULL
         res@metadata$station <- station
-        res@metadata$deploymentType <- "unknown"
         res@metadata$date <- date
         res@metadata$startTime <- startTime
+        res@metadata$recoveryTime <- recoveryTime
         res@metadata$latitude <- latitude
         res@metadata$longitude <- longitude
-        res@metadata$recovery <- recovery
+        res@metadata$deploymentType <- deploymentType
         res@metadata$waterDepth <- max(abs(data$pressure), na.rm=TRUE) # not in header
         res@metadata$sampleInterval <- sampleInterval
         ##res@metadata$names <- names
@@ -584,12 +587,12 @@ read.ctd.woce <- function(file, columns=NULL, station=NULL, missingValue, monito
         res@metadata$address <- address
         res@metadata$cruise <- NULL
         res@metadata$station <- station
-        res@metadata$deploymentType <- "unknown"
         res@metadata$date <- date
         res@metadata$startTime <- startTime
+        res@metadata$recoveryTime <- recoveryTime
         res@metadata$latitude <- latitude
         res@metadata$longitude <- longitude
-        res@metadata$recovery <- recovery
+        res@metadata$deploymentType <- deploymentType
         res@metadata$waterDepth <- waterDepth
         res@metadata$sampleInterval <- sampleInterval
         ##res@metadata$names <- names
@@ -643,14 +646,17 @@ read.ctd.woce <- function(file, columns=NULL, station=NULL, missingValue, monito
 }
 
 #' Read a WOCE-type CTD file with First Word "EXPOCODE"
+#'
 #' @template readCtdTemplate
 #'
+#' @author Dan Kelley
+#'
 #' @details
 #' \code{read.ctd.woce.other()} reads files stored in the exchange format used
 #' by the World Ocean Circulation Experiment (WOCE), in which the first
 #' word in the file is \code{EXPOCODE}.
-read.ctd.woce.other <- function(file, columns=NULL, station=NULL, missingValue, monitor=FALSE,
-                                debug=getOption("oceDebug"), processingLog, ...)
+read.ctd.woce.other <- function(file, columns=NULL, station=NULL, missingValue, deploymentType="unknown",
+                                monitor=FALSE, debug=getOption("oceDebug"), processingLog, ...)
 {
     ##EXPOCODE 06MT18/1      WHP-ID A1E    DATE 090591
     ##STNNBR    558 CASTNO   1 NO.RECORDS=   83
@@ -723,5 +729,6 @@ read.ctd.woce.other <- function(file, columns=NULL, station=NULL, missingValue,
     } else {
         warning("problem assigning units\n")
     }
+    res@metadata$deploymentType <- deploymentType
     res
 }
