@@ -180,8 +180,8 @@ julianDay <- function(t, year=NA, month=NA, day=NA, hour=NA, min=NA, sec=NA, tz=
 #'
 #' Convert a Julian-Day number to a time in julian centuries since noon on
 #' January 1, 1900.
-#' The method follows Meese (1982 equation 15.1).  The example reproduces the
-#' example provided by Meeuse (1982 example 15.a), with fractional error 3e-8.
+#' The method follows Meeus (1982 equation 15.1).  The example reproduces the
+#' example provided by Meeus (1982 example 15.a), with fractional error 3e-8.
 #'
 #' @param jd a julian day number, e.g. as given by \code{\link{julianDay}}.
 #' @return Julian century since noon on January 1, 1900.
@@ -220,7 +220,7 @@ julianCenturyAnomaly <- function(jd)
 #' \code{\link{equatorialToLocalHorizontal}}.
 #'
 #' @param t time, a POSIXt object (converted to timezone \code{"UTC"},
-#' if it is not already in that timezone), or a numeric value that
+#' if it is not already in that timezone), a character or numeric value that
 #' corresponds to such a time.
 #' @param longitude observer longitude in degrees east
 #' @param latitude observer latitude in degrees north
@@ -267,7 +267,7 @@ julianCenturyAnomaly <- function(jd)
 #' y <- 2012
 #' m <- 4
 #' days <- 1:3
-#' ## Halifax sunrise/sunset (see e.g. http://www.timeanddate.com/worldclock)
+#' ## Halifax sunrise/sunset (see e.g. https://www.timeanddate.com/worldclock)
 #' rises <- ISOdatetime(y, m, days,c(13,15,16), c(55, 04, 16),0,tz="UTC") + 3 * 3600 # ADT
 #' sets <- ISOdatetime(y, m,days,c(3,4,4), c(42, 15, 45),0,tz="UTC") + 3 * 3600
 #' azrises <- c(69, 75, 82)
@@ -289,7 +289,11 @@ julianCenturyAnomaly <- function(jd)
 #' @family things related to astronomy
 moonAngle <- function(t, longitude=0, latitude=0, useRefraction=TRUE)
 {
-    if (missing(t)) stop("must give 't'")
+    if (missing(t)) stop("must provide 't'")
+    if (is.character(t))
+        t <- as.POSIXct(t, tz="UTC")
+    else if (inherits(t, "Date"))
+        t <- as.POSIXct(t)
     if (!inherits(t, "POSIXt")) {
         if (is.numeric(t)) {
             tref <- as.POSIXct("2000-01-01 00:00:00", tz="UTC") # arbitrary
@@ -298,10 +302,10 @@ moonAngle <- function(t, longitude=0, latitude=0, useRefraction=TRUE)
             stop("t must be POSIXt or a number corresponding to POSIXt (in UTC)")
         }
     }
-    if ("UTC" != attr(as.POSIXct(t[1]), "tzone"))
+    ## Ensure that the timezone is UTC. Note that Sys.Date() gives a NULL tzone.
+    tzone <- attr(as.POSIXct(t[1]), "tzone")
+    if (is.null(tzone) || "UTC" != tzone)
         attributes(t)$tzone <- "UTC"
-    if (missing(longitude)) stop("must give 'longitude'")
-    if (missing(latitude)) stop("must give 'latitude'")
     RPD <- atan2(1, 1) / 45            # radians per degree
     ## In this cde, the symbol names follow [1] Meeus 1982 chapter 30, with e.g. "p"
     ## used to indicate primes, e.g. Lp stands for L' in Meeus' notation.
