@@ -28,8 +28,8 @@
 #'
 #' @author Dan Kelley and Clark Richards
 #'
-#' @family classes provided by \code{oce}
-#' @family things related to \code{rsk} data
+#' @family classes provided by oce
+#' @family things related to rsk data
 setClass("rsk", contains="oce")
 
 #' @title Sample Rsk Dataset
@@ -52,8 +52,8 @@ setClass("rsk", contains="oce")
 #' plot(rsk)
 #' plot(as.ctd(rsk))
 #'
-#' @family datasets provided with \code{oce}
-#' @family things related to \code{rsk} data
+#' @family datasets provided with oce
+#' @family things related to rsk data
 NULL
 
 
@@ -74,7 +74,7 @@ setMethod(f="initialize",
               ## 20160515 ## .Object@metadata$units$pressure <- list(unit=expression(dbar), scale="")
               .Object@metadata$pressureType <- "absolute"
               .Object@metadata$pressureAtmospheric <- 10.1325
-              .Object@processingLog$time <- as.POSIXct(Sys.time())
+              .Object@processingLog$time <- presentTime()
               .Object@processingLog$value <- "create 'rsk' object"
               return(.Object)
           })
@@ -100,7 +100,7 @@ setMethod(f="initialize",
 #'
 #' @author Dan Kelley
 #'
-#' @family things related to \code{rsk} data
+#' @family things related to rsk data
 setMethod(f="summary",
           signature="rsk",
           definition=function(object, ...) {
@@ -121,7 +121,7 @@ setMethod(f="summary",
 #' @param x A rsk object, i.e. one inheriting from \code{\link{rsk-class}}.
 #' @template sub_subTemplate
 #' @author Dan Kelley
-#' @family things related to \code{rsk} data
+#' @family things related to rsk data
 setMethod(f="[[",
           signature(x="rsk", i="ANY", j="ANY"),
           definition=function(x, i, j, ...) {
@@ -131,7 +131,7 @@ setMethod(f="[[",
 #' @title Replace Parts of a Rsk Object
 #' @param x An \code{rsk} object, i.e. inheriting from \code{\link{rsk-class}}
 #' @template sub_subsetTemplate
-#' @family things related to \code{rsk} data
+#' @family things related to rsk data
 setMethod(f="[[<-",
           signature(x="rsk", i="ANY", j="ANY"),
           definition=function(x, i, j, ..., value) {
@@ -164,8 +164,8 @@ setMethod(f="[[<-",
 #' plot(subset(rsk, time < mean(range(rsk[['time']]))))
 #'
 #' @author Dan Kelley
-#' @family things related to \code{rsk} data
-#' @family functions that subset \code{oce} objects
+#' @family things related to rsk data
+#' @family functions that subset oce objects
 setMethod(f="subset",
           signature="rsk",
           definition=function(x, subset, ...) {
@@ -252,6 +252,8 @@ unitFromStringRsk <- function(s)
         list(unit=expression(degree*C), scale="ITS-90") # guessing on scale
     else if (1 == length(grep("\\xc2\\xb5Mol/m\\xc2\\xb2/s", s, useBytes=TRUE))) # µMol/m²/s
         list(unit=expression(mu*mol/m^2/s), scale="")
+    else if (is.na(s))
+        list(unit=expression(), scale="?")
     else {
         warning("'", s, "' is not in the list of known .rsk units", sep="")
         list(unit=as.expression(s), scale="")
@@ -298,7 +300,7 @@ unitFromStringRsk <- function(s)
 #' An object of \code{\link{rsk-class}} \code{"rsk"}.
 #'
 #' @author Dan Kelley
-#' @family things related to \code{rsk} data
+#' @family things related to rsk data
 as.rsk <- function(time, columns,
                    filename="", instrumentType="rbr", serialNumber="", model="",
                    sampleInterval=NA,
@@ -426,8 +428,8 @@ as.rsk <- function(time, columns,
 #'
 #' @author Dan Kelley and Clark Richards
 #'
-#' @family functions that plot \code{oce} data
-#' @family things related to \code{rsk} data
+#' @family functions that plot oce data
+#' @family things related to rsk data
 #' @aliases plot.rsk
 setMethod(f="plot",
           signature=signature("rsk"),
@@ -622,7 +624,7 @@ setMethod(f="plot",
 #'
 #' @author Dan Kelley and Clark Richards
 #'
-#' @family things related to \code{rsk} data
+#' @family things related to rsk data
 read.rsk <- function(file, from=1, to, by=1, type, tz=getOption("oceTz", default="UTC"),
                         patm=FALSE, processingLog, debug=getOption("oceDebug"))
 {
@@ -717,10 +719,14 @@ read.rsk <- function(file, from=1, to, by=1, type, tz=getOption("oceTz", default
         rskv <- dbInfo[1, 1]
         rskVersion <- as.numeric(strsplit(gsub(".[a-z].*$", "", gsub("^.*- *", "", rskv)), "\\.")[[1]])
         ## Ruskin software version number
-        appSettings <- RSQLite::dbReadTable(con, "appSettings")
-        rv <- appSettings[1, 2]
-        ##OLD rv <- read.table(pipe(cmd), sep="|")[1, 2]
-        ruskinVersion <- as.numeric(strsplit(gsub(".[a-z].*$", "", gsub("^.*- *", "", rv)), "\\.")[[1]])
+        if (RSQLite::dbExistsTable(con, "appSettings")) {
+            appSettings <- RSQLite::dbReadTable(con, "appSettings")
+            rv <- appSettings[1, 2]
+            ##OLD rv <- read.table(pipe(cmd), sep="|")[1, 2]
+            ruskinVersion <- as.numeric(strsplit(gsub(".[a-z].*$", "", gsub("^.*- *", "", rv)), "\\.")[[1]])
+        } else {
+            ruskinVersion <- "mobile"
+        }
         ##message("NEW: ruskinVersion: ", paste(ruskinVersion, collapse="."))
         ## Next block got triggered with too many files, and it seems more sensible
         ## to just go ahead and try to get something from the file as best we can.
@@ -742,6 +748,11 @@ read.rsk <- function(file, from=1, to, by=1, type, tz=getOption("oceTz", default
         }, silent=TRUE)
         if (warn)
             warning("non-standard pressureAtmospheric value: ", pressureAtmospheric)
+        ## some cases can have an empty pressureAtmospheric
+        if (length(pressureAtmospheric) == 0) {
+            warning("empty pressureAtmospheric value in rsk file. Setting to default value of 10.1325")
+            pressureAtmospheric <- 10.1325
+        }
         ##message("NEW: pressureAtmospheric:", pressureAtmospheric)
         oceDebug(debug, "after studying the RSK file, now have pressureAtmospheric=", pressureAtmospheric, "\n")
 
@@ -771,25 +782,25 @@ read.rsk <- function(file, from=1, to, by=1, type, tz=getOption("oceTz", default
             } else if (inherits(to, 'character')) {
                 to <- as.character(as.numeric(as.POSIXct(to, tz=tz))*1000)
             } else if (is.numeric(to)) {
-                res <- DBI::dbSendQuery(con,
-                                        if (packageVersion("RSQLite") < "2.0")
-                                            "select 1.0*tstamp from data order by tstamp;"
-                                        else
-                                            "select tstamp from data order by tstamp;")
-                t1000 <- DBI::dbFetch(res, n=-1)[[1]]
-                RSQLite::dbClearResult(res)
+                qres <- DBI::dbSendQuery(con,
+                                         if (packageVersion("RSQLite") < "2.0")
+                                             "select 1.0*tstamp from data order by tstamp;"
+                                         else
+                                             "select tstamp from data order by tstamp;")
+                t1000 <- DBI::dbFetch(qres, n=-1)[[1]]
+                RSQLite::dbClearResult(qres)
                 time <- numberAsPOSIXct(as.numeric(t1000) / 1000, type='unix')
             }
         }
 
         if (is.numeric(from) & from != 1 & all(is.na(time))) {
-            res <- DBI::dbSendQuery(con,
-                                    if (packageVersion("RSQLite") < "2.0")
-                                        "select 1.0*tstamp from data order by tstamp;"
-                                    else
-                                        "select tstamp from data order by tstamp;")
-            t1000 <- DBI::dbFetch(res, n=-1)[[1]]
-            RSQLite::dbClearResult(res)
+            qres <- DBI::dbSendQuery(con,
+                                     if (packageVersion("RSQLite") < "2.0")
+                                         "select 1.0*tstamp from data order by tstamp;"
+                                     else
+                                         "select tstamp from data order by tstamp;")
+            t1000 <- DBI::dbFetch(qres, n=-1)[[1]]
+            RSQLite::dbClearResult(qres)
             time <- numberAsPOSIXct(as.numeric(t1000) / 1000, type='unix')
         }
 
@@ -813,22 +824,22 @@ read.rsk <- function(file, from=1, to, by=1, type, tz=getOption("oceTz", default
         ## Generate the sql that contains the time filters
         if (missing(to)) {
             if (is.numeric(from)) {
-                res <- DBI::dbSendQuery(con, paste(sql_fields, ";"))
+                qres <- DBI::dbSendQuery(con, paste(sql_fields, ";"))
             } else {
-                res <- DBI::dbSendQuery(con, paste(sql_fields, "where tstamp >=",  from, ";"))
+                qres <- DBI::dbSendQuery(con, paste(sql_fields, "where tstamp >=",  from, ";"))
             }
         } else {
             if (missing(to)) {
-                res <- DBI::dbSendQuery(con, paste(sql_fields, "where tstamp >=",  from, ";"))
+                qres <- DBI::dbSendQuery(con, paste(sql_fields, "where tstamp >=",  from, ";"))
             } else if (from==1) {
-                res <- DBI::dbSendQuery(con, paste(sql_fields, "where tstamp <=",  to, ";"))
+                qres <- DBI::dbSendQuery(con, paste(sql_fields, "where tstamp <=",  to, ";"))
             } else {
-                res <- DBI::dbSendQuery(con, paste(sql_fields, "where tstamp between",  from, "and", to, ";"))
+                qres <- DBI::dbSendQuery(con, paste(sql_fields, "where tstamp between",  from, "and", to, ";"))
             }
         }
 
         ## Now, get only the specified time range
-        data <- DBI::dbFetch(res, n=-1)
+        data <- DBI::dbFetch(qres, n=-1)
         data <- data[order(data$tstamp),]
         time <- numberAsPOSIXct(as.numeric(data[,1])/1000, type='unix')
 
@@ -840,7 +851,7 @@ read.rsk <- function(file, from=1, to, by=1, type, tz=getOption("oceTz", default
             data <- data[, -grep('datasetID', names(data)), drop=FALSE]
         }
         data <- data[,c(-1), drop=FALSE] # drop the corrupted time column
-        DBI::dbClearResult(res)
+        DBI::dbClearResult(qres)
         ## Get column names from the 'channels' table.
         names <- tolower(RSQLite::dbReadTable(con, "channels")$longName)
         ## FIXME: some longnames have UTF-8 characters, and/or
@@ -857,9 +868,11 @@ read.rsk <- function(file, from=1, to, by=1, type, tz=getOption("oceTz", default
             isMeasured <- channelsTable$isMeasured == 1
         } else {
             isMeasured <- channelsTable$isDerived == 0
-            warning("old Ruskin file detected; if problems arise, update file with Ruskin software")
+            ##warning("old Ruskin file detected; if problems arise, update file with Ruskin software")
         }
         dataNamesOriginal <- c("-", channelsTable$shortName[isMeasured])
+        ##1491> message("below is dataNamesOriginal: (at start)");print(dataNamesOriginal)
+        ##[issue 1483] print(cbind(channelsTable,isMeasured))
         names <- names[isMeasured] # only take names of things that are in the data table
         unitsRsk <- channelsTable$units[isMeasured]
         ## Check for duplicated names, and append digits to make unique
@@ -881,6 +894,7 @@ read.rsk <- function(file, from=1, to, by=1, type, tz=getOption("oceTz", default
         sampleInterval <- schedules$samplingPeriod/1000 # stored as milliseconds in rsk
         RSQLite::dbDisconnect(con)
         res <- new("rsk", time=time, filename=filename)
+        res@metadata$dataNamesOriginal <- dataNamesOriginal
         for (iname in seq_along(names)) {
             res@data[[names[iname]]] <- data[[names[iname]]]
             res@metadata$units[[names[iname]]] <- unitFromStringRsk(unitsRsk[iname])
@@ -892,6 +906,8 @@ read.rsk <- function(file, from=1, to, by=1, type, tz=getOption("oceTz", default
             }
         }
         res@metadata$units$pressure$scale <- "absolute"
+        ##1491> message("res@metadata$dataNamesOriginal L909:");print(res@metadata$dataNamesOriginal)
+        ##?browser()
         if ("pressure" %in% names) {
             ## possibly compute sea pressure
             if (is.logical(patm)) {
@@ -903,7 +919,7 @@ read.rsk <- function(file, from=1, to, by=1, type, tz=getOption("oceTz", default
                     res@metadata$units$pressureOriginal <- list(unit=expression(dbar), scale="absolute")
                     res@data$pressure <- res@data$pressureOriginal - 10.1325
                     res@metadata$units$pressure <- list(unit=expression(dbar), scale="sea")
-                    res@metadata$dataNamesOriginal <- c(res@metadata$dataNamesOriginal, "")
+                    res@metadata$dataNamesOriginal <- c(res@metadata$dataNamesOriginal, "-")
                     res@metadata$pressureType <- "sea"
                     oceDebug(debug, "patm=TRUE, so removing std atmospheric pressure, 10.1325 dbar\n")
                 }
@@ -919,24 +935,50 @@ read.rsk <- function(file, from=1, to, by=1, type, tz=getOption("oceTz", default
                 res@metadata$units$pressureOriginal <- list(unit=expression(dbar), scale="absolute")
                 res@data$pressure <- res@data$pressureOriginal - patm
                 res@metadata$units$pressure <- list(unit=expression(dbar), scale="sea")
-                res@metadata$dataNamesOriginal <- c(res@metadata$dataNamesOriginal, "")
+                res@metadata$dataNamesOriginal <- c(res@metadata$dataNamesOriginal, "-")
                 res@metadata$pressureType <- "sea"
             } else {
                 stop("patm must be logical or numeric")
             }
         }
+        ##1491> message("res@metadata$dataNamesOriginal L944:");print(res@metadata$dataNamesOriginal)
         res@metadata$model <- model
         res@metadata$serialNumber <- serialNumber
         res@metadata$sampleInterval <- sampleInterval
         res@metadata$rskVersion <- rskVersion
         res@metadata$ruskinVersion <- ruskinVersion
-        res@metadata$dataNamesOriginal <- as.list(dataNamesOriginal)
+        ##1491> message("res@metadata$dataNamesOriginal L951:");print(res@metadata$dataNamesOriginal)
+        ##1491> message("names(res@data) L952:");print(names(res@data))
+        ## HERE
         names(res@metadata$dataNamesOriginal) <- names(res@data)
         if (hasDatasetID) res@metadata$datasetID <- datasetID
         ## There is actually no need to set the conductivity unit since new()
         ## sets it, but do it anyway, as a placeholder to show where to do
-        ## this, in case some RBR devices use different units
-        res@metadata$units$conductivity <- list(unit=expression(mS/cm), scale="") # FIXME: will this work for all RBR rsks?
+        ## this, in case some RBR devices use different units.
+        if ("cond12" %in% names(res@data)) {
+            ## [issue 1483] Change the name, and possibly unit, of 'cond12'
+            ##
+            ## For a sample file, channelsTable gives the unit for cond12 as
+            ## NA.  Rather than make unitFromStringRsk() give a conductivity
+            ## unit whenever it gets an NA value (which might occur for other
+            ## fields -- who knows?), we will switch NA to uS/cm because
+            ## that seems to be the usual unit for RBR instruments. However,
+            ## if the cond12 unit is not NA, we will leave it as it is, on the
+            ## assumption that unitFromStringRsk() has already interpreted
+            ## it correctly
+            w <- which("cond12" == names)[1]
+            if (is.na(unitsRsk[w])) {
+                res@metadata$units$cond12 <- NULL # remove existing
+                res@metadata$units$conductivity <- list(unit=expression(mS/cm), scale="")
+            }
+            newnames <- gsub("cond12", "conductivity", names(res@data))
+            names(res@data) <- newnames
+            names(res@metadata$dataNamesOriginal) <- newnames
+        } else {
+            ## FIXME: will this work for all RBR rsks that don't contain cond12?
+            res@metadata$units$conductivity <- list(unit=expression(mS/cm), scale="")
+        }
+        ##1491> message("str(dataNamesOriginal) L984:");print(res@metadata$dataNamesOriginal)
         res@metadata$pressureAtmospheric <- pressureAtmospheric
         res@processingLog <- processingLogAppend(res@processingLog, paste(deparse(match.call()), sep="", collapse=""))
         oceDebug(debug, "} # read.rsk()\n", sep="", unindent=1)
@@ -1322,7 +1364,7 @@ rsk2ctd <- function(x, pressureAtmospheric=0, longitude=NULL, latitude=NULL,
 #'
 #' @author Dan Kelley
 #'
-#' @family things related to \code{rsk} data
+#' @family things related to rsk data
 rskPatm <- function(x, dp=0.5)
 {
     p <- if (inherits(x, "rsk")) x@data$pressure else x
@@ -1371,12 +1413,12 @@ rskPatm <- function(x, dp=0.5)
 #' indicating to print information about the processing.
 #'
 #' @examples
-#' \dontrun{
+#'\dontrun{
 #' table <- rskToc("/data/archive/sleiwex/2008/moorings/m05/adv/sontek_202h/raw",
 #' from=as.POSIXct("2008-07-01 00:00:00", tz="UTC"),
 #'     to=as.POSIXct("2008-07-01 12:00:00", tz="UTC"))
 #' print(table)
-#' }
+#'}
 #'
 #' @return
 #' A list with two elements: \code{filename}, a vector of file names, and
@@ -1385,7 +1427,7 @@ rskPatm <- function(x, dp=0.5)
 #'
 #' @author Dan Kelley
 #'
-#' @family things related to \code{rsk} data
+#' @family things related to rsk data
 rskToc <- function(dir, from, to, debug=getOption("oceDebug"))
 {
     if (missing(dir))
