@@ -205,3 +205,61 @@ test_that("stationReplaceAllStations", {
           expect_true("N2" %in% names(section[["station",1]][["data"]]))
 })
 
+test_that("sectionGrid units and flags", {
+          data(section)
+          ## Work with a subset for speed of test.
+          s <- subset(section, 115<=stationId&stationId<=121)
+          sg <- sectionGrid(s, p=seq(0, 5000, 500))
+          ## Check flag names (in this dataset, all stations have same flags)
+          expect_equal(sort(names(section[["station",1]][["flags"]]), method="radix"),
+                         sort(names(sg[["station",1]][["flags"]]), method="radix"))
+          ## Check units (in this dataset, all stations have same units)
+          expect_equal(section[["station",1]][["units"]], sg[["station",1]][["units"]])
+})
+
+test_that("sectionSmooth units and flags", {
+          data(section)
+          ## Work with a subset for speed of test.
+          s <- subset(section, 115<=stationId&stationId<=121)
+          ## NOTE: there's no need to check other methods besides "spline",
+          ## because units and flags are handled in code that applies to all
+          ## methods.
+          sspline <- sectionSmooth(sectionGrid(s, p=seq(0, 5000, 500)), "spline")
+          ## Check flag names (in this dataset, all stations have same flags)
+          expect_equal(sort(names(sspline[["station",1]][["flags"]]), method="radix"),
+                       sort(names(s[["station",1]][["flags"]]), method="radix"))
+          ## Check units (in this dataset, all stations have same units)
+          expect_equal(sspline[["station",1]][["units"]], s[["station",1]][["units"]])
+})
+
+test_that("sectionSmooth profile count", {
+          data(section)
+          s <- subset(section, 115<=stationId&stationId<=121)
+          sg <- sectionGrid(s, p=seq(0, 5000, 500))
+          sspline <- sectionSmooth(sg, "spline")
+          expect_equal(length(s[["station"]]), length(sspline[["station"]]))
+          ## Check dimensionality when xg is given
+          sspline2 <- sectionSmooth(sg, "spline", xg=seq(0,200,50))
+          expect_equal(length(sspline2[["station"]]), 5)
+          sbarnes <- sectionSmooth(s, "barnes", xr=50, yr=200)
+          expect_equal(length(s[["station"]]), length(sbarnes[["station"]]))
+          if (requireNamespace("automap", quietly=TRUE) &&
+              requireNamespace("sp", quietly=TRUE)) {
+            expect_warning(skrigingInternal <- sectionSmooth(s, "kriging"), "NaNs produced")
+            expect_equal(length(s[["station"]]), length(skrigingInternal[["station"]]))
+            expect_warning(skrigingInternal2 <- sectionSmooth(s, "kriging", xg=seq(0,200,50)), "NaNs produced")
+            expect_equal(length(skrigingInternal2[["station"]]), 5)
+            krigFunction <- function(x, y, F, xg, xr, yg, yr) {
+              xy <- data.frame(x=x/xr, y=y/yr)
+              K <- automap::autoKrige(F~1, remove_duplicates=TRUE,
+                                      input_data=sp::SpatialPointsDataFrame(xy, data.frame(F)),
+                                      new_data=sp::SpatialPoints(expand.grid(xg/xr, yg/yr)))
+              matrix(K$krige_output@data$var1.pred, nrow=length(xg), ncol=length(yg))
+            }
+            expect_warning(skrigingUser <- sectionSmooth(s, krigFunction), "NaNs produced")
+            expect_equal(length(skrigingUser[["station"]]), length(s[["station"]]))
+            expect_warning(skrigingUser2 <- sectionSmooth(s, krigFunction, xg=seq(0,200,50)), "NaNs produced")
+            expect_equal(length(skrigingUser2[["station"]]), 5)
+          }
+})
+
